@@ -2,7 +2,7 @@
 # Author:        rmp
 # Maintainer:    $Author: rmp $
 # Created:       2004-02-16
-# Last Modified: $Date: 2007/11/20 20:12:21 $
+# Last Modified: $Date: 2007/01/26 23:10:41 $
 #
 # Builds DAS features from Phenotypic Abnormalities Database
 #
@@ -24,7 +24,7 @@ use strict;
 use warnings;
 use base qw(Bio::Das::ProServer::SourceAdaptor);
 
-our $VERSION = do { my @r = (q$Revision: 2.70 $ =~ /\d+/g); sprintf '%d.'.'%03d' x $#r, @r };
+our $VERSION = do { my @r = (q$Revision: 2.50 $ =~ /\d+/g); sprintf '%d.'.'%03d' x $#r, @r };
 
 sub init {
   my $self                = shift;
@@ -47,7 +47,7 @@ sub build_features {
   # pretty duff valid chromosome check, but catches most clone ids quickly
   #
   return if(CORE::length($seg) > 2);
-  
+
   #########
   # retrieve patient data
   #
@@ -58,7 +58,7 @@ sub build_features {
     $qbounds  = 'AND sc.chr_start <= ? AND ec.chr_end >= ?';
     push @args, ($end, $start);
   }
-  
+
   my $patientquery = qq(SELECT STRAIGHT_JOIN a.patient_id          AS id,
 			       p.submitter_groupname AS curator,
 			       p.project_id          AS project_id,
@@ -74,18 +74,14 @@ sub build_features {
                                clone           sc,
                                clone           ec,
                                clone           hsc,
-                               clone           hec,
-                               feature_type    ft
+                               clone           hec
 			WHERE  p.consent        = 'Y'
-                        AND    p.parent        != 'Y'
 			AND    f.array_id       = a.id
 			AND    a.patient_id     = p.id
 			AND    sc.name          = f.soft_start_clone_name
 			AND    ec.name          = f.soft_end_clone_name
 			AND    hsc.name         = f.hard_start_clone_name
 			AND    hec.name         = f.hard_end_clone_name
-                        AND    ft.id            = f.type_id
-                        AND    ft.description   not like '%cnv%'
 			AND    sc.chr           = ?
 			AND    ec.chr           = ?
 			AND    hsc.chr          = ?
@@ -96,36 +92,35 @@ sub build_features {
 			AND    hec.arraytype_id = a.arraytype_id $qbounds
                        	GROUP BY a.patient_id,sc.name,ec.name
 			ORDER BY a.patient_id);
-  
+
   my $plinktmpl = $self->config->{'patientlink'}       || '%s:%s';
   my $slinktmpl = $self->config->{'syndromelink'}      || '%s:%s';
   my $tlinktmpl = $self->config->{'translocationlink'} || '%s:%s:%s';
   my @features  = ();
   my $fid       = 1;
   my $gid       = 1;
-  
+
   for my $patient (@{$self->transport->query($patientquery, @args)}) {
     my $id             = $patient->{'id'};
-    my $curator        = $patient->{'curator'};
     my $phenotypequery = qq(SELECT description
 			    FROM   phenotype c, patient_class pc, patient p
 			    WHERE  pc.patient_id = ?
 			    AND    pc.class_id   = c.id
 			    AND    p.id          = pc.patient_id
 			    @{[($consentcheck eq 'yes')?q(AND p.consent = 'Y'):'']});
-    
-    my $lbl          = sprintf('%08d',  $id); #If DECIPHER member then display id with submitter group name
+
+    my $lbl          = sprintf('%08d',  $id); #sr5: need to remove the center codes:
     my $classes      = $self->transport->query($phenotypequery, $id);
-    
+
     my $classtxt     = join(', ', map { $_->{'description'} } @{$classes});
     my $chr_interval = $patient->{'soft_end'} - $patient->{'soft_start'};
-    
+
     #########
     # feature
     #
     my ($hardstart, $hardend) = ($patient->{'hard_start'}, $patient->{'hard_end'});
     ($hardend, $hardstart)    = ($hardstart, $hardend) if($hardend < $hardstart);
-    
+
     my $mr = $patient->{'type'};
     my $cc = '';
     if($mr < -1) {
@@ -141,7 +136,7 @@ sub build_features {
     } elsif($mr >= 1) {
       $cc = 5;
     }
-    
+
     push @features, {
 		     'id'           => $fid++,
 		     'label'        => $lbl,
@@ -161,13 +156,13 @@ sub build_features {
 		     'note'         => $classtxt || '',
 		     'groupnote'    => $classtxt || '',
 		    };
-    
+
     #########
     # fuzzy, surrounding feature
     #
     my ($softstart, $softend) = ($patient->{'soft_start'}, $patient->{'soft_end'}); #need to fix these error bars - also need to deal with overlaps i.e. upstream + downstream clones.
     ($softend, $softstart)    = ($softstart, $softend) if($softend < $softstart);
-    
+
     push @features, {
 		     'id'           => $fid++,
 		     'type'         => sprintf('decipher:%s:%s:soft',
@@ -188,9 +183,9 @@ sub build_features {
 		    };
     $gid++;
   }
-  
-  #########################
-  # retrieve Syndromes ...
+
+  #########
+  # retrieve
   #
   
   my $syndromequery = qq(SELECT ks.id                AS id,
@@ -217,7 +212,7 @@ sub build_features {
                                  syndrome_class ksc
 			  WHERE  ksc.syndrome_id = ?
 			  AND    ksc.class_id    = c.id);
-  
+
   @args = ();
   push @args, ($end, $start) if($qbounds);
   for my $syndrome (@{$self->transport->query($syndromequery, $seg, $seg, @args)}) {
@@ -226,9 +221,9 @@ sub build_features {
     my $classes      = $self->transport->query($phenotypequery, $id);
     my $classtxt     = join(', ', map { $_->{'description'} } @{$classes});
     my $chr_interval = $syndrome->{'hard_end'} - $syndrome->{'hard_start'};
-    
+
     #########
-    # build feature
+    # feature
     #
     my ($hardstart, $hardend) = ($syndrome->{'hard_start'}, $syndrome->{'hard_end'});
     ($hardend, $hardstart)    = ($hardstart, $hardend) if($hardend < $hardstart);
@@ -272,18 +267,20 @@ sub build_features {
                                      b.topology              AS topology,
                                      tf.strand               AS tf_strand,
                                      p.project_id            AS project_id
-                              FROM   patient                p,
+                              FROM   translocation_clone    tc,
                                      translocation          t,
                                      breakpoint             b,
+                                     patient                p,
                                      translocation_features tf,
-                                     translocation_clone    tc
-                                     straight_join clone sc on (sc.arraytype_id=tc.arraytype_id)
-                                     straight_join clone ec on (sc.arraytype_id=tc.arraytype_id)
+                                     clone                  sc,
+                                     clone                  ec
                               WHERE  t.patient_id                 = p.id
                               AND    tf.translocation_clone_id    = tc.id
                               AND    tc.translocation_id          = t.id
                               AND    tc.start_clone_name          = sc.name
                               AND    tc.end_clone_name            = ec.name
+                              AND    sc.arraytype_id              = tc.arraytype_id
+                              AND    ec.arraytype_id              = tc.arraytype_id
                               AND    b.translocation_clone_id     = tc.id
                               AND    p.consent                    = 'Y'
                               AND    sc.chr                       = ?
@@ -302,12 +299,12 @@ sub build_features {
                                       tc.id           AS translocation_clone_id,
                                       t.id            AS trans_id,
                                       t.translocation_type_id AS type_id
-                               FROM   patient                p,
+                               FROM   translocation_clone    tc,
                                       translocation          t,
+                                      patient                p,
                                       translocation_features tf,
-                                      translocation_clone    tc
-                                      straight_join clone sc on (sc.arraytype_id=tc.arraytype_id)
-                                      straight_join clone ec on (sc.arraytype_id=tc.arraytype_id)
+                                      clone                  sc,
+                                      clone                  ec
                                WHERE  t.patient_id                 = p.id
                                AND    tf.translocation_clone_id    = tc.id
                                AND    tc.translocation_id          = t.id
@@ -436,6 +433,7 @@ sub build_features {
     my $clone_start  = $sc_tstart; 
     my $clone_end    =($type_id == 6 && $start_clone ne $end_clone)?$ec_tend:$sc_tend;
     if($type_id == 6){
+      print STDERR "BPSTART_one:$bpstart and BPEND_one: $bpend\n";
       print STDERR "BPSTART:$bpstart_two and CLONE START: $clone_start\n";
       print STDERR "BPEND: $bpend_two and CLONE END: $clone_end\n";
       print STDERR "CLONES: $start_clone ($sc_tstart, $sc_tend) AND $end_clone ($ec_tstart, $ec_tend)";
